@@ -4,6 +4,7 @@
 import unittest
 from mock import MagicMock, patch
 from uiautomator import JsonRPCMethod, JsonRPCClient
+import os
 
 
 class TestJsonRPCMethod_id(unittest.TestCase):
@@ -26,18 +27,26 @@ class TestJsonRPCMethod_call(unittest.TestCase):
         self.method = JsonRPCMethod(self.url, self.method_name, self.timeout)
         self.method.id = MagicMock()
         self.method.id.return_value = self.id
-        self.method.pool = MagicMock()
-        self.urlopen = self.method.pool.urlopen
+        try:
+            import urllib2
+            self.urlopen_patch = patch('urllib2.urlopen')
+        except:
+            self.urlopen_patch = patch('urllib.request.urlopen')
+        finally:
+            self.urlopen = self.urlopen_patch.start()
+
+    def tearDown(self):
+        self.urlopen_patch.stop()
 
     def test_normal_call(self):
         return_mock = self.urlopen.return_value
-        return_mock.status = 200
+        return_mock.getcode.return_value = 200
 
-        return_mock.data = b'{"result": "pong", "error": null, "id": "DKNCJDLDJJ"}'
+        return_mock.read.return_value = b'{"result": "pong", "error": null, "id": "DKNCJDLDJJ"}'
         self.assertEqual("pong", self.method())
         self.method.id.assert_called_once_with()
 
-        return_mock.data = b'{"result": "pong", "id": "JDLSFJLILJEMNC"}'
+        return_mock.read.return_value = b'{"result": "pong", "id": "JDLSFJLILJEMNC"}'
         self.assertEqual("pong", self.method())
         self.assertEqual("pong", self.method(1, 2, "str", {"a": 1}, ["1"]))
         self.assertEqual("pong", self.method(a=1, b=2))
@@ -45,17 +54,18 @@ class TestJsonRPCMethod_call(unittest.TestCase):
     def test_normal_call_error(self):
         return_mock = self.urlopen.return_value
 
-        return_mock.status = 500
+        return_mock.getcode.return_value = 500
         with self.assertRaises(Exception):
             self.method()
 
-        return_mock.status = 200
-        return_mock.data = b'{"result": "pong", "error": {"code": -513937, "message": "error message."}, "id": "fGasV62G"}'
+        return_mock.getcode.return_value = 200
+        return_mock.read.return_value = b'{"result": "pong", "error": {"code": -513937, "message": "error message."}, "id": "fGasV62G"}'
         with self.assertRaises(Exception):
             self.method()
+        return_mock.read.assert_called_with()
 
-        return_mock.status = 200
-        return_mock.data = b'{"result": null, "error": null, "id": "fGasV62G"}'
+        return_mock.getcode.return_value = 200
+        return_mock.read.return_value = b'{"result": null, "error": null, "id": "fGasV62G"}'
         with self.assertRaises(SyntaxError):
             self.method(1, 2, kwarg1="")
 
@@ -76,3 +86,41 @@ class TestJsonRPCClient(unittest.TestCase):
             JsonRPCMethod.return_value = {"width": 10, "height": 20}
             self.assertEqual(client.info, {"width": 10, "height": 20})
             JsonRPCMethod.assert_called_with(self.url, "info", timeout=self.timeout)
+
+
+class TestJsonRPCMethod_call_on_windows(unittest.TestCase):
+
+    def setUp(self):
+        self.os_name = os.name
+        os.name = "nt"
+        self.url = "http://localhost/jsonrpc"
+        self.timeout = 20
+        self.method_name = "ping"
+        self.id = "fGasV62G"
+        self.method = JsonRPCMethod(self.url, self.method_name, self.timeout)
+        self.method.pool = MagicMock()
+        self.method.id = MagicMock()
+        self.method.id.return_value = self.id
+
+    def tearDown(self):
+        os.name = self.os_name
+
+    def test_normal_call(self):
+        urlopen = self.method.pool.urlopen
+        urlopen.return_value.status = 200
+
+        urlopen.return_value.data = b'{"result": "pong", "error": null, "id": "DKNCJDLDJJ"}'
+        self.assertEqual("pong", self.method())
+        self.method.id.assert_called_once_with()
+
+        urlopen.return_value.data = b'{"result": "pong", "id": "JDLSFJLILJEMNC"}'
+        self.assertEqual("pong", self.method())
+        self.assertEqual("pong", self.method(1, 2, "str", {"a": 1}, ["1"]))
+        self.assertEqual("pong", self.method(a=1, b=2))
+
+    def test_normal_call_error(self):
+        urlopen = self.method.pool.urlopen
+        urlopen.return_value.status = 500
+
+        with self.assertRaises(Exception):
+            self.method()
